@@ -42,15 +42,18 @@ class DictProxy(dict):
         return super(dict, self).__getattr__(name, default) 
 
 
-def Connector(url, username, password, list_id, timeout=15):
+def Connector(url, username, password, list_id, timeout=65):
     """ Sharepoint SOAP connector factory """
     transport = WindowsHttpAuthenticated(username=username,
                                          password=password,
                                          timeout=timeout)
-    client = Client(url, transport=transport)
-    client.set_options(service='Lists', port='ListsSoap12')
+
+    if not 'Lists.asxml' in url:
+        url = url + '/_vti_bin/Lists.asmx?WSDL'
 
     try:
+        client = Client(url, transport=transport)
+        client.set_options(service='Lists', port='ListsSoap12')
         return ListEndpoint(client, list_id)
     except Exception, e:
         # *try* to capture authentication related error.
@@ -172,7 +175,9 @@ class ListEndpoint(object):
     def getItems(self, rowLimit=999999999, viewName=None):
         """ Return all list items without further filtering """
         items = self.service.GetListItems(self.list_id, viewName=viewName or self.viewName, rowLimit=rowLimit)
-        return [self._serializeListItem(item) for item in items.listitems.data.row]
+        if items.listitems.data._ItemCount > 0:
+            return [self._serializeListItem(item) for item in items.listitems.data.row]
+        return []
 
     def getItem(self, item_id, viewName=None):
         """ Return all list items without further filtering """
